
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.015.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => "6.30",
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Easy LWP tracing and debugging",
  "dist_author" => [
    "Olaf Alders <olaf\@wundercounter.com>"
  ],
  "dist_name" => "LWP-ConsoleLogger",
  "dist_version" => "0.000002",
  "license" => "perl",
  "module_name" => "LWP::ConsoleLogger",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "DateTime" => 0,
    "Email::MIME" => 0,
    "Email::MIME::ContentType" => 0,
    "HTML::Restrict" => 0,
    "HTTP::CookieMonster" => 0,
    "Log::Dispatch" => 0,
    "Moose" => 0,
    "MooseX::StrictConstructor" => 0,
    "MooseX::Types::Common::Numeric" => 0,
    "MooseX::Types::Moose" => 0,
    "Sub::Exporter" => 0,
    "Term::Size::Any" => 0,
    "Text::SimpleTable::AutoWidth" => 0,
    "URI::Query" => 0,
    "URI::QueryParam" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "HTTP::Request" => 0,
    "LWP::UserAgent" => 0,
    "Path::Tiny" => 0,
    "Test::Fatal" => 0,
    "Test::Most" => 0,
    "URI::file" => 0,
    "WWW::Mechanize" => 0
  }
);


my %fallback_build_requires = (
  "HTTP::Request" => 0,
  "LWP::UserAgent" => 0,
  "Module::Build" => "0.3601",
  "Path::Tiny" => 0,
  "Test::Fatal" => 0,
  "Test::Most" => 0,
  "URI::file" => 0,
  "WWW::Mechanize" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
